@@ -50,6 +50,8 @@ class Denom:
     def load_peggy_denom(cls, network, symbol):
         if network == 'devnet':
             config = devnet_config
+        elif network == 'local':
+            config = devnet_config
         elif network == 'testnet':
             config = testnet_config
         else:
@@ -122,5 +124,16 @@ class Network:
             env='mainnet'
         )
 
+    @classmethod
+    def local(cls):
+        return cls(
+            lcd_endpoint="localhost:10337",
+            grpc_endpoint="localhost:9900",
+            grpc_exchange_endpoint="localhost:9910",
+            chain_id='injective-1',
+            fee_denom='inj',
+            env='local'
+        )
+
     def string(self):
         return self.env
